@@ -60,7 +60,7 @@ public final class LayoutUtil
 
 	private static WeakHashMap<Object, String> CR_MAP = null;
 	private static WeakHashMap<Object, Boolean> DT_MAP = null;      // The Containers that have design time. Value not used.
-	private static int eSz = 15;
+	private static int eSz = 0;
 	private static int globalDebugMillis = 0;
 
 	private LayoutUtil()
@@ -72,7 +72,7 @@ public final class LayoutUtil
 	 */
 	public static String getVersion()
 	{
-		return "3.7";
+		return "3.7.2";
 	}
 
 	/** If global debug should be on or off. If &gt; 0 then debug is turned on for all MigLayout
@@ -144,7 +144,9 @@ public final class LayoutUtil
 	}
 
 	/** The size of an empty row or columns in a grid during design time.
-	 * @param pixels The number of pixels. Default is 15.
+	 * @param pixels The number of pixels. Default is 0 (it was 15 prior to v3.7.2, but since that meant different behaviour
+	 * under design time by default it was changed to be 0, same as non-design time). IDE vendors can still set it to 15 to
+	 * get the old behaviour.
 	 */
 	public static void setDesignTimeEmptySize(int pixels)
 	{
