@@ -127,6 +127,7 @@ public final class PlatformDefaults
 
 	private static int LP_BASE = BASE_SCALE_FACTOR;
 
+	private static Integer BASE_DPI_FORCED = null;
 	private static int BASE_DPI = 96;
 
 	private static boolean dra = true;
@@ -162,10 +163,6 @@ public final class PlatformDefaults
 	 */
 	public static void setPlatform(int plaf)
 	{
-		if (plaf < WINDOWS_XP || plaf > GNOME)
-			throw new IllegalArgumentException("Unknown platform: " + plaf);
-
-		CUR_PLAF = plaf;
 		switch (plaf) {
 			case WINDOWS_XP:
 				setRelatedGap(LPX4, LPY4);
@@ -178,7 +175,6 @@ public final class PlatformDefaults
 				setButtonOrder("L_E+U+YNBXOCAH_R");
 				setDialogInsets(LPY11, LPX11, LPY11, LPX11);
 				setPanelInsets(LPY7, LPX7, LPY7, LPX7);
-				BASE_DPI = 96;
 				break;
 			case MAC_OSX:
 				setRelatedGap(LPX4, LPY4);
@@ -202,11 +198,6 @@ public final class PlatformDefaults
 //				setButtonOrder("L_HE+U+NYBXCOA_R");
 //				setDialogInsets(LPY14, LPX20, LPY20, LPX20);
 //				setPanelInsets(LPY16, LPX16, LPY16, LPX16);
-				try {
-					BASE_DPI = System.getProperty("java.version").compareTo("1.6") < 0 ? 72 : 96; // Default DPI was 72 prior to JSE 1.6
-				} catch (Throwable t) {
-					BASE_DPI = 72;
-				}
 				break;
 			case GNOME:
 				setRelatedGap(LPX6, LPY6);                    // GNOME HIG 8.2.3
@@ -220,7 +211,28 @@ public final class PlatformDefaults
 				setButtonOrder("L_HE+UNYACBXIO_R");           // GNOME HIG 3.4.2, 3.7.1
 				setDialogInsets(LPY12, LPX12, LPY12, LPX12);  // GNOME HIG 3.4.3
 				setPanelInsets(LPY6, LPX6, LPY6, LPX6);       // ???
-				BASE_DPI = 96;
+				break;
+			default:
+				throw new IllegalArgumentException("Unknown platform: " + plaf);
+		}
+		CUR_PLAF = plaf;
+		BASE_DPI = BASE_DPI_FORCED != null ? BASE_DPI_FORCED.intValue() : getPlatformDPI(plaf);
+	}
+
+	private static int getPlatformDPI(int plaf)
+	{
+		switch (plaf) {
+			case WINDOWS_XP:
+			case GNOME:
+				return 96;
+			case MAC_OSX:
+				try {
+					return System.getProperty("java.version").compareTo("1.6") < 0 ? 72 : 96; // Default DPI was 72 prior to JSE 1.6
+				} catch (Throwable t) {
+					return 72;
+				}
+			default:
+				throw new IllegalArgumentException("Unknown platform: " + plaf);
 		}
 	}
 
@@ -237,6 +249,18 @@ public final class PlatformDefaults
 		return BASE_DPI;
 	}
 
+	/** Sets the default plaform DPI. Normally this is set in the {@link #setPlatform(int)} for the different platforms
+	 * but it can be tweaked here. For instance SWT on Mac does this.
+	 * <p>
+	 * Note that this is not the actual current DPI, but the base DPI for the toolkit.
+	 * @param dpi The base DPI. If null the default DPI is reset to the platform base DPI.
+	 */
+	public static void setDefaultDPI(Integer dpi)
+	{
+		BASE_DPI = dpi != null ? dpi.intValue() : getPlatformDPI(CUR_PLAF);
+		BASE_DPI_FORCED = dpi;
+	}
+
 	/** The forced scale factor that all screen relative units (e.g. millimeters, inches and logical pixels) will be multiplied
 	 * with. If <code>null</code> this will default to a scale that will scale the current screen to the default screen resolution
 	 * (72 DPI for Mac and 92 DPI for Windows).
