@@ -73,6 +73,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	private transient int lastModCount = PlatformDefaults.getModCount();
 	private transient int lastHash = -1;
 	private transient Dimension lastInvalidSize = null;
+	private transient boolean lastWasInvalid = false;  // Added in 3.7.1. May have regressions
 
 	private transient ArrayList<LayoutCallback> callbackList = null;
 
@@ -293,7 +294,7 @@ public final class MigLayout implements LayoutManager2, Externalizable
 	private void setComponentConstraintsImpl(Component comp, Object constr, boolean noCheck)
 	{
 		Container parent = comp.getParent();
-		synchronized(parent.getTreeLock()) {
+		synchronized(parent != null ? parent.getTreeLock() : new Object()) { // 3.7.2. No sync if not added to a hierarchy. Defeats a NPE.
 			if (noCheck == false && scrConstrMap.containsKey(comp) == false)
 				throw new IllegalArgumentException("Component must already be added to parent!");
 
@@ -433,22 +434,27 @@ public final class MigLayout implements LayoutManager2, Externalizable
 		}
 
 		if (parent.isValid() == false) {
+			if (lastWasInvalid == false) {
+				lastWasInvalid = true;
 
-			int hash = 0;
-			for (Iterator<ComponentWrapper> it = ccMap.keySet().iterator(); it.hasNext();)
-				hash += it.next().getLayoutHashCode();
+				int hash = 0;
+				for (Iterator<ComponentWrapper> it = ccMap.keySet().iterator(); it.hasNext();)
+					hash += it.next().getLayoutHashCode();
 
-			if (hash != lastHash) {
-				grid = null;
-				lastHash = hash;
-			}
+				if (hash != lastHash) {
+					grid = null;
+					lastHash = hash;
+				}
 
-			Dimension ps = parent.getSize();
-			if (lastInvalidSize == null || !lastInvalidSize.equals(ps)) {
-				if (grid != null)
-					grid.invalidateContainerSize();
-				lastInvalidSize = ps;
+				Dimension ps = parent.getSize();
+				if (lastInvalidSize == null || !lastInvalidSize.equals(ps)) {
+					if (grid != null)
+						grid.invalidateContainerSize();
+					lastInvalidSize = ps;
+				}
 			}
+		} else {
+			lastWasInvalid = false;
 		}
 
 		ContainerWrapper par = checkParent(parent);
@@ -496,13 +502,20 @@ public final class MigLayout implements LayoutManager2, Externalizable
 			long newSize = grid.getHeight()[1] + (((long) grid.getWidth()[1]) << 32);
 			if (lastSize != newSize) {
 				lastSize = newSize;
-				SwingUtilities.invokeLater(new Runnable() { // Added 2008-12-04
-					public void run() {
-						adjustWindowSize(checkParent(parent));
-					}
-				});
+				final ContainerWrapper containerWrapper = checkParent(parent);
+				Window win = ((Window) SwingUtilities.getAncestorOfClass(Window.class, (Component)containerWrapper.getComponent()));
+				if (win != null) {
+				   if (win.isVisible()) {
+					   SwingUtilities.invokeLater(new Runnable() {
+						   public void run() {
+							   adjustWindowSize(containerWrapper);
+						   }
+					   });
+				   } else {
+					   adjustWindowSize(containerWrapper);
+				   }
+				}
 			}
-
 			lastInvalidSize = null;
 		}
 	}
